==> input-select-1.0.0.tgz: package/src/mixins/common-select.js <==
import isEqual from 'lodash/isEqual';
import isArray from 'lodash/isArray';
import map from 'lodash/map';
import find from 'lodash/find';
import isEmpty from 'lodash/isEmpty';
import mixinInputValidator from '@meta-vue/mixin-input-validator';

import 'vue-search-select/dist/VueSearchSelect.css';
import '@mdi/font/css/materialdesignicons.css';

export default {
  data() {
    return {
      selected: isArray(this.value) ? [] : '',
      clearIcon: 'mdi-close'
    };
  },

  created() {
    this.selected = isArray(this.value)
      ? map(this.value, item =>
          find(this.computedOptions, option => option.value === item)
        )
      : this.value;
  },

  props: {
    /** Define if the option setted can be clearable */
    clearable: {
      type: Boolean,
      required: false,
      clearable: true
    },
    /** Array with options */
    options: {
      type: Array,
      required: false,
      default: () => []
    }
  },

  computed: {
    clearButtonIsEmpty() {
      return !this.$slots.clearButtonHtml;
    },
    valueIsEmpty() {
      return isEmpty(this.value);
    },
    computedOptions() {
      return map(this.options, ({ value, label }) => ({ value, text: label }));
    }
  },

  watch: {
    selected(selected) {
      let newSelected = selected;
      let newValue = selected;

      if (isArray(selected)) {
        newSelected = map(selected, item =>
          find(this.computedOptions, option => option.value === item.value)
        );
        newValue = map(newSelected, ({ value }) => value);
      }

      if (!isEqual(newValue, this.value)) {
        const event = { target: { value: newValue } };

        this.onChange(event);
        if (!this.validator.touched) {
          this.onBlur(event);
        }
      }
    },
    value(value) {
      let newSelected = value;

      if (!isEqual(value, this.value)) {
        if (isArray(value)) {
          newSelected = map(value, item =>
            find(this.computedOptions, option => option.value === item)
          );
        }

        const event = { target: { value } };

        this.onChange(event);
        if (!this.validator.touched) {
          this.selected = newSelected;
          this.onBlur(event);
        }
      }
    }
  },

  mixins: [mixinInputValidator]
};

==> input-select-1.0.14.tgz: package/src/mixins/common-select.js <==
import isEqual from 'lodash/isEqual';
import isArray from 'lodash/isArray';
import map from 'lodash/map';
import find from 'lodash/find';
import isEmpty from 'lodash/isEmpty';
import mixinInputValidator from '@meta-vue/mixin-input-validator';

import 'vue-search-select/dist/VueSearchSelect.css';
import '@mdi/font/css/materialdesignicons.css';

export default {
  data() {
    return {
      selected: isArray(this.value) ? [] : '',
      clearIcon: 'mdi-close'
    };
  },

  created() {
    this.selected = isArray(this.value)
      ? map(this.value, item =>
          find(this.computedOptions, option => option.value === item)
        )
      : this.value;
  },

  props: {
    /** Define if the option setted can be clearable */
    clearable: {
      type: Boolean,
      required: false,
      default: true
    },
    /** Array with options */
    options: {
      type: Array,
      required: false,
      default: () => []
    }
  },

  computed: {
    clearButtonIsEmpty() {
      return !this.$slots.clearButtonHtml;
    },
    enableClear() {
      return this.clearable && !isEmpty(this.value);
    },
    computedOptions() {
      return map(this.options, ({ value, label }) => ({ value, text: label }));
    }
  },

  watch: {
    selected(selected) {
      let newSelected = selected;
      let newValue = selected;

      if (isArray(selected)) {
        newSelected = map(selected, item =>
          find(this.computedOptions, option => option.value === item.value)
        );
        newValue = map(newSelected, ({ value }) => value);
      }

      if (!isEqual(newValue, this.value)) {
        const event = { target: { value: newValue } };

        this.onChange(event);
        if (!this.validator.touched) {
          this.onBlur(event);
        }
      }
    },
    value(value) {
      let newSelected = value;

      if (!isEqual(value, this.value)) {
        if (isArray(value)) {
          newSelected = map(value, item =>
            find(this.computedOptions, option => option.value === item)
          );
        }

        const event = { target: { value } };

        this.onChange(event);
        if (!this.validator.touched) {
          this.selected = newSelected;
          this.onBlur(event);
        }
      }
    }
  },

  mixins: [mixinInputValidator]
};
